/*
	Speaker.h
	Application Kit, Release 2.0
	Copyright (c) 1988, NeXT, Inc.  All rights reserved. 
*/

#import <objc/Object.h>
#import <mach/message.h>
#import <mach/port.h>

#define NX_ISFILE 0
#define NX_ISDIRECTORY 1
#define NX_ISAPPLICATION 2
#define NX_ISODMOUNT 3
#define NX_ISNETMOUNT 4
#define NX_ISSCSIMOUNT 5
#define NX_ISFLOPPYMOUNT 6

@interface Speaker : Object
{
    port_t              sendPort;
    port_t              replyPort;
    int                 sendTimeout;
    int                 replyTimeout;
    id                  delegate;
    int                 _reservedSpeaker1;
    int                 _reservedSpeaker2;
}

- init;
- free;
- delegate;
- setDelegate:anObject;
- (port_t)sendPort;
- setSendPort:(port_t)aPort;
- (port_t)replyPort;
- setReplyPort:(port_t)aPort;
- (int)sendTimeout;
- setSendTimeout:(int)ms;
- (int)replyTimeout;
- setReplyTimeout:(int)ms;
- (int)performRemoteMethod:(const char *)msgSelector;
- (int)performRemoteMethod:(const char *)msgSelector with:(const char *)data length:(int)numBytes;
- (int)selectorRPC:(const char *)msgSelector paramTypes:(char *)params, ...;
- write:(NXTypedStream *)stream;
- read:(NXTypedStream *)stream;

/* use [Application workspace] instead of these messages unless you need to send them to the port of a specific app */
- (int)sendOpenFileMsg:(const char *)fullPath ok:(int *)flag andDeactivateSelf:(BOOL)doDeact;
- (int)sendOpenTempFileMsg:(const char *)fullPath ok:(int *)flag andDeactivateSelf:(BOOL)doDeact;
- (int)openFile:(const char *)fullPath ok:(int *)flag;
- (int)openTempFile:(const char *)fullPath ok:(int *)flag;

- (int)msgQuit:(int *)flag;
- (int)msgCalc:(int *)flag;
- (int)msgDirectory:(char * const *)fullPath ok:(int *)flag;
- (int)msgVersion:(char * const *)aString ok:(int *)flag;
- (int)msgFile:(char * const *)fullPath ok:(int *)flag;
- (int)msgPrint:(const char *)fullPath ok:(int *)flag;
- (int)msgSelection:(char * const *)bytes length:(int *)len asType:(const char *)aType ok:(int *)flag;
- (int)msgSetPosition:(const char *)aString posType:(int)anInt andSelect:(int)sflag ok:(int *)flag;
- (int)msgPosition:(char * const *)aString posType:(int *)anInt ok:(int *)flag;
- (int)msgCopyAsType:(const char *)aType ok:(int *)flag;
- (int)msgCutAsType:(const char *)aType ok:(int *)flag;
- (int)msgPaste:(int *)flag;

/* 
 * The following new... methods are now obsolete.  They remain in this  
 * interface file for backward compatibility only.  Use Object's alloc method  
 * and the init... methods defined in this class instead.
 */
+ new;

@end
